@@ -7,8 +7,6 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
 /* 1/1/89: NB:  this stuff is all going to be replaced.  Don't take it too seriously */
 /*
 
@@ -18,7 +16,11 @@
 
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/vol/volume.c,v 1.12 2001/08/08 00:04:23 shadow Exp $");
+
 #include <rx/xdr.h>
 #include <afs/afsint.h>
 #include <ctype.h>
@@ -33,10 +35,15 @@
 #ifdef	AFS_SUN5_ENV
 #include <sys/fs/ufs_fs.h>
 #else
+#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#include <ufs/ufs/dinode.h>
+#include <ufs/ffs/fs.h>
+#else
 #include <ufs/fs.h>
 #endif
+#endif
 #else /* AFS_VFSINCL_ENV */
-#if !defined(AFS_AIX_ENV) && !defined(AFS_LINUX20_ENV)
+#if !defined(AFS_AIX_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_FBSD_ENV)
 #include <sys/fs.h>
 #endif
 #endif /* AFS_VFSINCL_ENV */
@@ -416,7 +423,7 @@ static void ReadHeader(Error *ec, IHandle_t *h, char *to, int size,
 void VolumeHeaderToDisk(VolumeDiskHeader_t *dh, VolumeHeader_t *h)
 {
 
-    bzero((char*)dh, sizeof(VolumeDiskHeader_t));
+    memset((char*)dh, 0, sizeof(VolumeDiskHeader_t));
     dh->stamp = h->stamp;
     dh->id = h->id;
     dh->parent = h->parent;
@@ -446,7 +453,7 @@ void VolumeHeaderToDisk(VolumeDiskHeader_t *dh, VolumeHeader_t *h)
  */
 void DiskToVolumeHeader(VolumeHeader_t *h, VolumeDiskHeader_t *dh)
 {
-    bzero((char*)h, sizeof(VolumeHeader_t));
+    memset((char*)h, 0, sizeof(VolumeHeader_t));
     h->stamp = dh->stamp;
     h->id = dh->id;
     h->parent = dh->parent;
@@ -546,11 +553,15 @@ VAttachVolumeByName_r(ec, partition, name, mode)
 	    if (vp->specialStatus == VBUSY)
 	        isbusy = 1;
 	    VDetachVolume_r(ec, vp);
+	    if ( *ec ) {
+		Log("VAttachVolume: Error detaching volume (%s)\n", name);
+	    }
 	}
     }
 
     if (!(partp = VGetPartition_r(partition, 0))) {
 	*ec = VNOVOL;
+	Log("VAttachVolume: Error getting partition (%s)\n", partition);
 	goto done;
     }
 
@@ -625,6 +636,7 @@ VAttachVolumeByName_r(ec, partition, name, mode)
 #endif
 	VUpdateVolume_r(ec,vp);
 	if (*ec) {
+	    Log("VAttachVolume: Error updating volume\n");
 	    if (vp)
 		VPutVolume_r(vp);
 	    goto done;
@@ -641,6 +653,7 @@ VAttachVolumeByName_r(ec, partition, name, mode)
 	    V_dontSalvage(vp) = DONT_SALVAGE;
 	    VAddToVolumeUpdateList_r(ec,vp);
 	    if (*ec) {
+		Log("VAttachVolume: Error adding volume to update list\n");
 		if (vp)
 		    VPutVolume_r(vp);
 		goto done;
@@ -694,6 +707,10 @@ private Volume *attach2(ec, path, header, partp, isbusy)
 		      (char *)&V_disk(vp), sizeof(V_disk(vp)), 
 		      VOLUMEINFOMAGIC, VOLUMEINFOVERSION);
     VOL_LOCK
+    if (*ec) {
+      Log("VAttachVolume: Error reading diskDataHandle vol header %s; error=%d\n",
+        path, *ec);
+    }
     if (!*ec) {
 	struct IndexFileHeader iHead;
 
@@ -704,7 +721,7 @@ private Volume *attach2(ec, path, header, partp, isbusy)
 	 * area and mark it as initialized.
 	 */
 	if (! (V_stat_initialized(vp))) {
-	    bzero((char *)(V_stat_area(vp)), VOL_STATS_BYTES);
+	    memset((char *)(V_stat_area(vp)), 0, VOL_STATS_BYTES);
 	    V_stat_initialized(vp) = 1;
 	}
 #endif /* TRANSARC_VOL_STATS */
@@ -713,6 +730,10 @@ private Volume *attach2(ec, path, header, partp, isbusy)
 			  (char *)&iHead, sizeof(iHead), 
 			  SMALLINDEXMAGIC, SMALLINDEXVERSION);
 	VOL_LOCK
+    	if (*ec) {
+  	    Log("VAttachVolume: Error reading smallVnode vol header %s; error=%d\n",
+	        path, *ec);
+	}
     }
     if (!*ec) {
 	struct IndexFileHeader iHead;
@@ -721,6 +742,10 @@ private Volume *attach2(ec, path, header, partp, isbusy)
 			  (char *)&iHead, sizeof(iHead),
 			  LARGEINDEXMAGIC, LARGEINDEXVERSION);
 	VOL_LOCK
+    	if (*ec) {
+  	    Log("VAttachVolume: Error reading largeVnode vol header %s; error=%d\n",
+	        path, *ec);
+	}
     }
 #ifdef AFS_NAMEI_ENV
     if (!*ec) {
@@ -730,11 +755,15 @@ private Volume *attach2(ec, path, header, partp, isbusy)
 			  (char *)&stamp, sizeof(stamp),
 			  LINKTABLEMAGIC, LINKTABLEVERSION);
 	VOL_LOCK
+    	if (*ec) {
+  	    Log("VAttachVolume: Error reading namei vol header %s; error=%d\n",
+	        path, *ec);
+	}
     }
 #endif
     if (*ec) {
-	Log("VAttachVolume: Error attaching volume %s; volume needs salvage\n",
-	    path);
+	Log("VAttachVolume: Error attaching volume %s; volume needs salvage; error=%d\n",
+	    path, *ec);
 	FreeVolume(vp);
 	return NULL;
     }
@@ -777,6 +806,7 @@ private Volume *attach2(ec, path, header, partp, isbusy)
 	    VOL_LOCK
 	    if (*ec) {
 		FreeVolume(vp);
+		Log("VAttachVolume: error getting bitmap for volume (%s)\n", path);
 		return NULL;
 	    }
 	}
@@ -1269,7 +1299,7 @@ int VAllocBitmapEntry_r(ec,vp,index)
     assert(bp != NULL);
     index->bitmap = bp;
     bp += index->bitmapSize;
-    bzero(bp, VOLUME_BITMAP_GROWSIZE);
+    memset(bp, 0, VOLUME_BITMAP_GROWSIZE);
     index->bitmapOffset = index->bitmapSize;
     index->bitmapSize += VOLUME_BITMAP_GROWSIZE;
     *bp = 1;
@@ -1564,7 +1594,7 @@ VAdjustVolumeStatistics_r(vp)
 	 * All we need to do is bzero the entire VOL_STATS_BYTES of
 	 * the detailed volume statistics area.
 	 */
-	bzero((char *)(V_stat_area(vp)), VOL_STATS_BYTES);
+	memset((char *)(V_stat_area(vp)), 0, VOL_STATS_BYTES);
 #endif /* TRANSARC_VOL_STATS */
     } /*It's been more than a day of collection*/
 
